package net.knarcraft.ffmpegconverter.converter;

import net.knarcraft.ffmpegconverter.streams.AudioStream;
import net.knarcraft.ffmpegconverter.streams.StreamObject;
import net.knarcraft.ffmpegconverter.utility.FFMpegHelper;

import java.io.File;
import java.io.IOException;
import java.util.List;

/**
 * A converter for converting audio files
 */
public class AudioConverter extends AbstractConverter {

    /**
     * Instantiates a new audio converter
     *
     * @param ffprobePath <p>Path/command to ffprobe.</p>
     * @param ffmpegPath  <p>Path/command to ffmpeg.</p>
     * @param newExtension      <p>The extension of the new file.</p>
     */
    public AudioConverter(String ffprobePath, String ffmpegPath, String newExtension) {
        super(newExtension);
        this.ffprobePath = ffprobePath;
        this.ffmpegPath = ffmpegPath;
    }

    @Override
    public String[] builderCommand(String executable, File file, List<StreamObject> streams, String outFile) {
        List<String> command = FFMpegHelper.getFFMpegGeneralFileCommand(executable, file.getName());
        List<AudioStream> audioStreams = filterStreamsByType(streams, "audio");
        AudioStream audioStream = null;
        if (audioStreams.size() > 0) {
            audioStream = audioStreams.get(0);
        }
        if (audioStreams.size() > 0) {
            command.add("-map");
            command.add("0:" + audioStream.getAbsoluteIndex());
        }
        command.add(outFile);
        return command.toArray(new String[0]);
    }

    @Override
    public String[] getValidFormats() {
        return audioFormats;
    }

    @Override
    public void convert(File file) throws IOException {
        processFile(file.getParentFile(), file);
    }
}